INSTALLATION
============

Any of the following method should work, though you will likely want  to do them
as an administrator:

If you have downloaded the zip file, unzip it and in the directory it was
unzipped to run the following command:

    python setup.py install

---

Alternatively, installation from PyPi can be accomplished using 

    easy_install blogtool

or

    pip install blogtool

---

If you want to do things the hard way:

    git clone git://github.com/lama7/blogtool blogtool
    cd blogtool
    python setup.py install
